@@ -27,10 +27,10 @@ class DadosCobranca(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
+    conta = models.ForeignKey("repositories_plataforma.Conta", db_column="conta_id")
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_dados_cobranca"
 
 
@@ -54,11 +54,11 @@ class DadosCobrancaCartao(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
-    dados_cobranca = models.ForeignKey("DadosCobranca", db_column="dados_cobranca_id")
+    conta = models.ForeignKey("repositories_plataforma.Conta", db_column="conta_id")
+    dados_cobranca = models.ForeignKey(DadosCobranca, db_column="dados_cobranca_id")
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_dados_cobranca_cartao"
 
 
@@ -111,11 +111,11 @@ class Fatura(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
-    contrato = models.ForeignKey("plataforma.Contrato", db_column="contrato_id")
+    conta = models.ForeignKey("repositories_plataforma.Conta", db_column="conta_id")
+    contrato = models.ForeignKey("repositories_plataforma.Contrato", db_column="contrato_id")
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_fatura"
 
 
@@ -133,11 +133,11 @@ class FaturaItem(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
-    fatura = models.ForeignKey("Fatura", db_column="fatura_id", related_name='itens')
+    conta = models.ForeignKey("repositories_plataforma.Conta", db_column="conta_id")
+    fatura = models.ForeignKey(Fatura, db_column="fatura_id", related_name='itens')
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_fatura_item"
 
 
@@ -151,7 +151,7 @@ class Colecao(models.Model):
     objects = MyObjects()
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_colecao"
 
 
@@ -169,10 +169,10 @@ class Plano(models.Model):
 
     objects = MyObjects()
 
-    colecao = models.ForeignKey("Colecao", db_column="colecao_id")
+    colecao = models.ForeignKey(Colecao, db_column="colecao_id")
 
     class Meta:
-        app_label = 'faturamento'
+        app_label = 'repositories_faturamento'
         db_table = u"faturamento\".\"tb_plano"
 
 
@@ -189,12 +189,12 @@ class PlanoAssinatura(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
-    plano = models.ForeignKey("Plano", db_column="plano_id")
-    fatura = models.ForeignKey("Fatura", db_column="fatura_id")
+    conta = models.ForeignKey("repositories_plataforma.Conta", db_column="conta_id")
+    plano = models.ForeignKey(Plano, db_column="plano_id")
+    fatura = models.ForeignKey(Fatura, db_column="fatura_id")
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_plano_assinatura"
 
 
@@ -221,12 +221,12 @@ class Tema(models.Model):
 
     objects = MyObjects()
 
-    colecao = models.ForeignKey("Colecao", db_column="colecao_id")
+    colecao = models.ForeignKey(Colecao, db_column="colecao_id")
 
     ativo = models.NullBooleanField(db_column="tema_ativo")
 
     class Meta:
-        app_label = 'faturamento'
+        app_label = 'repositories_faturamento'
         db_table = u"faturamento\".\"tb_tema"
 
 
@@ -248,12 +248,12 @@ class Banner(models.Model):
 
     objects = MyObjects()
 
-    colecao = models.ForeignKey("Colecao", db_column="colecao_id")
+    colecao = models.ForeignKey(Colecao, db_column="colecao_id")
 
     ativo = models.NullBooleanField(db_column="banner_ativo")
 
     class Meta:
-        app_label = 'faturamento'
+        app_label = 'repositories_faturamento'
         db_table = u"faturamento\".\"tb_banner"
 
 
@@ -268,8 +268,8 @@ class Consumo(models.Model):
     trafego = models.BigIntegerField(db_column="consumo_trafego", default=0)
     visitas = models.BigIntegerField(db_column="consumo_visitas", default=0)
 
-    conta = models.ForeignKey("plataforma.Conta", db_column="conta_id")
+    conta = models.ForeignKey("repositories_plataforma.Conta", db_column="conta_id")
 
     class Meta:
-        app_label = "faturamento"
+        app_label = "repositories_faturamento"
         db_table = u"faturamento\".\"tb_consumo"
