@@ -35,11 +35,11 @@ class PedidoVendaSituacao(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_situacoes', null=True, default=None)
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_situacoes', null=True, default=None)
+    conta = models.ForeignKey('repositories_plataforma.Conta', related_name='pedido_venda_situacoes', null=True, default=None)
+    contrato = models.ForeignKey('repositories_plataforma.Contrato', related_name='pedido_venda_situacoes', null=True, default=None)
 
     class Meta:
-        app_label = "pedido"
+        app_label = "repositories_pedido"
         db_table = u"pedido\".\"tb_pedido_venda_situacao"
         verbose_name = u'Situação do pedido de venda'
         verbose_name_plural = u"Situações de pedidos de vendas"
@@ -50,51 +50,6 @@ class PedidoVendaSituacao(models.Model):
         return self.nome
 
 
-class PedidoVendaSituacaoHistorico(models.Model):
-    """Histórico de situações de um pedido de venda.
-
-    O alterado_por pode receber três valores básicos:
-        cliente - Quando foi o cliente que alterou.
-        gateway - Quando a alteração foi feita pelo gateway de pagamento.
-        usuario - Sempre que o usuário alterar a situação.
-        sistema - Quando não é possível identificar quem fez a alteração.
-    """
-    ALTERADO_POR_CLIENTE = 'cliente'
-    ALTERADO_POR_GATEWAY = 'gateway'
-    ALTERADO_POR_USUARIO = 'usuario'
-    ALTERADO_POR_SISTEMA = 'sistema'
-
-    CHOICES_ALTERADO_POR = [
-        (ALTERADO_POR_CLIENTE, u'Cliente'),
-        (ALTERADO_POR_GATEWAY, u'Gateway'),
-        (ALTERADO_POR_USUARIO, u'Usuário'),
-        (ALTERADO_POR_SISTEMA, u'Sistema'),
-    ]
-
-    id = models.AutoField(db_column="pedido_venda_situacao_historico_id", primary_key=True)
-    data = models.DateTimeField(db_column="pedido_venda_situacao_historico_data", auto_now=True)
-    alterado_por = models.CharField(db_column="pedido_venda_situacao_historico_alterado_por", max_length=64, null=True, choices=CHOICES_ALTERADO_POR)
-    alterado_por_nome = models.CharField(db_column="pedido_venda_situacao_historico_alterado_por_nome", max_length=128, null=True)
-
-    objects = MyObjects()
-
-    situacao_inicial = models.ForeignKey('pedido.PedidoVendaSituacao', db_column="pedido_venda_situacao_id_inicial", related_name='pedido_venda_situacao_inicial_historico')
-    situacao_final = models.ForeignKey('pedido.PedidoVendaSituacao', db_column="pedido_venda_situacao_id_final", related_name='pedido_venda_situacao_final_historico')
-    pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='historico', on_delete=models.CASCADE)
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_situacao_historico')
-    # contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_situacao_historico')
-
-    class Meta:
-        app_label = "pedido"
-        db_table = u"pedido\".\"tb_pedido_venda_situacao_historico"
-        verbose_name = u'Histórico de situações de um pedido de venda'
-        verbose_name_plural = u"Histórico de situações dos pedidos de vendas"
-        ordering = ['id']
-
-    def __unicode__(self):
-        return unicode(self.id)
-
-
 class PedidoVendaTipo(models.Model):
     """Tipo de pedido de venda."""
     id = models.AutoField(db_column="pedido_venda_tipo_id", primary_key=True)
@@ -103,7 +58,7 @@ class PedidoVendaTipo(models.Model):
     objects = MyObjects()
 
     class Meta:
-        app_label = "pedido"
+        app_label = "repositories_pedido"
         db_table = u"pedido\".\"tb_pedido_venda_tipo"
         verbose_name = u'Tipo de pedido de venda'
         verbose_name_plural = u"Tipos de pedidos de vendas"
@@ -145,11 +100,11 @@ class PedidoVendaEndereco(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("plataforma.Conta", related_name="pedido_venda_enderecos")
-    contrato = models.ForeignKey("plataforma.Contrato", related_name="pedido_venda_enderecos")
+    conta = models.ForeignKey("repositories_plataforma.Conta", related_name="pedido_venda_enderecos")
+    contrato = models.ForeignKey("repositories_plataforma.Contrato", related_name="pedido_venda_enderecos")
 
     class Meta:
-        app_label = "pedido"
+        app_label = "repositories_pedido"
         db_table = u"pedido\".\"tb_pedido_venda_endereco"
         verbose_name = u'Endereço do pedido de venda'
         verbose_name_plural = u"Endereços de pedidos de vendas"
@@ -159,34 +114,6 @@ class PedidoVendaEndereco(models.Model):
         return unicode(self.id)
 
 
-class PedidoVendaFormaEnvio(models.Model):
-    """Forma de envio de um pedido de venda."""
-    id = models.AutoField(db_column="pedido_venda_envio_id", primary_key=True)
-    objeto = models.CharField(db_column="pedido_venda_envio_objeto", max_length=32, null=True)
-    valor = models.DecimalField(db_column="pedido_venda_envio_valor", max_digits=16, decimal_places=2, null=True)
-    data_criacao = models.DateTimeField(db_column="pedido_venda_envio_data_criacao", auto_now_add=True)
-    data_modificacao = models.DateTimeField(db_column="pedido_venda_envio_data_modificacao", auto_now=True)
-    mensagem_correios = models.TextField(db_column="pedido_venda_envio_mensagem_correios", null=True, default=None)
-    prazo = models.IntegerField(db_column='pedido_venda_envio_prazo', null=True, default=None)
-
-    objects = MyObjects()
-
-    pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='pedido_envios')
-    envio = models.ForeignKey('configuracao.Envio', related_name='pedidos_envio')
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_envios')
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_envios')
-
-    class Meta:
-        app_label = "pedido"
-        db_table = u"pedido\".\"tb_pedido_venda_envio"
-        verbose_name = u'Forma de envio de um pedido de venda'
-        verbose_name_plural = u"Formas de envios dos pedidos de vendas"
-        ordering = ['id']
-
-    def __unicode__(self):
-        return unicode(self.id)
-
-
 class PedidoVendaFormaPagamento(models.Model):
     """Forma de pagamento de um pedido de venda."""
     id = models.AutoField(db_column="pedido_venda_pagamento_id", primary_key=True)
@@ -202,14 +129,14 @@ class PedidoVendaFormaPagamento(models.Model):
 
     objects = MyObjects()
 
-    banco = models.ForeignKey('configuracao.Banco', db_column='banco_id', related_name='banco')
-    pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='pedido_pagamentos')
-    pagamento = models.ForeignKey('configuracao.FormaPagamento', related_name='pedidos_pagamento')
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_pagamentos')
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_pagamentos')
+    banco = models.ForeignKey('repositories_configuracao.Banco', db_column='banco_id', related_name='banco')
+    pedido = models.ForeignKey('repositories_pedido.PedidoVenda', db_column='pedido_venda_id', related_name='pedido_pagamentos')
+    pagamento = models.ForeignKey('repositories_configuracao.FormaPagamento', related_name='pedidos_pagamento')
+    conta = models.ForeignKey('repositories_plataforma.Conta', related_name='pedido_venda_pagamentos')
+    contrato = models.ForeignKey('repositories_plataforma.Contrato', related_name='pedido_venda_pagamentos')
 
     class Meta:
-        app_label = "pedido"
+        app_label = "repositories_pedido"
         db_table = u"pedido\".\"tb_pedido_venda_pagamento"
         verbose_name = u'Forma de pagamento de um pedido de venda'
         verbose_name_plural = u"Formas de pagamentos dos pedidos de vendas"
@@ -247,27 +174,29 @@ class PedidoVenda(models.Model):
     conteudo_json = JSONField(db_column="pedido_venda_conteudo_json", null=True)
     numero_nota_fiscal = models.BigIntegerField(db_column="pedido_venda_numero_nota_fiscal", null=True)
 
-    _endereco_entrega = models.OneToOneField('pedido.PedidoVendaEndereco', db_column='pedido_venda_endereco_entrega_id', related_name='+', null=False)
-    _endereco_pagamento = models.OneToOneField('pedido.PedidoVendaEndereco', db_column='pedido_venda_endereco_pagamento_id', related_name='+', null=False)
+    _endereco_entrega = models.OneToOneField(PedidoVendaEndereco, db_column='pedido_venda_endereco_entrega_id', related_name='+', null=False)
+    _endereco_pagamento = models.OneToOneField(PedidoVendaEndereco, db_column='pedido_venda_endereco_pagamento_id', related_name='+', null=False)
 
     objects = MyObjects()
 
-    tipo = models.ForeignKey('pedido.PedidoVendaTipo', db_column='pedido_venda_tipo_id', related_name='pedidos')
-    situacao = models.ForeignKey('pedido.PedidoVendaSituacao', db_column='pedido_venda_situacao_id', related_name='pedidos')
-    cliente = models.ForeignKey('cliente.Cliente', related_name='pedidos')
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedidos_vendas', on_delete=models.CASCADE)
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedidos_vendas')
-    # cupom = models.ForeignKey("marketing.CupomDesconto", db_column='cupom_desconto_id', related_name='pedidos', null=True)
-    envios = models.ManyToManyField('configuracao.Envio', through='PedidoVendaFormaEnvio', related_name='pedidos')
-    pagamentos = models.ManyToManyField('configuracao.FormaPagamento', through='PedidoVendaFormaPagamento', related_name='pedidos')
+    tipo = models.ForeignKey(PedidoVendaTipo, db_column='pedido_venda_tipo_id', related_name='pedidos')
+    situacao = models.ForeignKey(PedidoVendaSituacao, db_column='pedido_venda_situacao_id', related_name='pedidos')
+    cliente = models.ForeignKey('repositories_cliente.Cliente', related_name='pedidos')
+    conta = models.ForeignKey('repositories_plataforma.Conta', related_name='pedidos_vendas', on_delete=models.CASCADE)
+    contrato = models.ForeignKey('repositories_plataforma.Contrato', related_name='pedidos_vendas')
+    cupom = models.ForeignKey("repositories_marketing.CupomDesconto", db_column='cupom_desconto_id', related_name='pedidos', null=True)
+    envios = models.ManyToManyField('repositories_configuracao.Envio', through='PedidoVendaFormaEnvio', related_name='pedidos')
+    pagamentos = models.ManyToManyField('repositories_configuracao.FormaPagamento', through='PedidoVendaFormaPagamento', related_name='pedidos')
 
     # A referência e o serviço são usados para identificar que este pedido
     # foi criado por algum serviço externo e depois importado na Loja Integerada
     # ou que ele foi criado na Loja Integrada e depois exportado para outro local.
     referencia = models.TextField(db_column='pedido_venda_referencia', null=True, default=None)
 
+    utm_campaign = models.CharField(max_length=255, db_column='pedido_venda_utm_campaign', null=True)
+
     class Meta:
-        app_label = "pedido"
+        app_label = "repositories_pedido"
         db_table = u"pedido\".\"tb_pedido_venda"
         verbose_name = u'Pedido Venda'
         verbose_name_plural = u'Pedidos de Venda'
@@ -278,6 +207,26 @@ class PedidoVenda(models.Model):
     def __unicode__(self):
         return unicode(self.id)
 
+    def save(self, *args, **kwargs):
+        if not self.numero and self.conta_id:
+            self.numero = self.conta.proximo_numero_pedido()
+
+        if not self.tipo_id:
+            self.tipo = PedidoVendaTipo.objects.get(pk=1)
+
+        if not self.situacao_id:
+            self.situacao = PedidoVendaSituacao.objects.get(padrao=True)
+
+        if self.cliente:
+            self.telefone_principal = self.cliente.telefone_principal
+            self.telefone_comercial = self.cliente.telefone_comercial
+            self.telefone_celular = self.cliente.telefone_celular
+
+        if self.conta and not self.contrato_id:
+            self.contrato_id = self.conta.contrato_id
+
+        super(self.__class__, self).save(*args, **kwargs)
+
     def criar_endereco(self, tipo, endereco):
         """Cria um endereço para o pedido baseado em um endereço do cliente."""
         # O tipo de endereço só pode ser pagamento ou entrega e o objeto deve
@@ -293,7 +242,7 @@ class PedidoVenda(models.Model):
             valores[campo] = getattr(endereco, campo)
             if campo in ['tipo', 'cpf', 'rg', 'cnpj', 'razao_social', 'ie']:
                 if not getattr(endereco, campo):
-                    valores[campo] = getattr(endereco.cliente.endereco(), campo)
+                    valores[campo] = getattr(endereco.cliente.endereco, campo)
 
         try:
             novo_endereco = PedidoVendaEndereco.objects.filter(
@@ -395,7 +344,7 @@ class PedidoVendaItem(models.Model):
     # Variação é um campo que armazena um json com os dados de um dicionário de
     # variações do produto, se o produto tem variação: Cor = Azul e Tamanho = P
     # o valor armazenado é: '{"Cor": "Azul", "Tamanho": "P"}'.
-    _variacao = models.TextField(db_column="pedido_venda_item_variacao", null=True)
+    variacao_json = JSONField(db_column="pedido_venda_item_variacao", null=True)
     peso = models.DecimalField(db_column="pedido_venda_item_peso", max_digits=16, decimal_places=3, default=None, null=True)
     altura = models.IntegerField(db_column="pedido_venda_item_altura", default=None, null=True)
     largura = models.IntegerField(db_column="pedido_venda_item_largura", default=None, null=True)
@@ -404,15 +353,15 @@ class PedidoVendaItem(models.Model):
 
     objects = MyObjects()
 
-    pedido = models.ForeignKey('pedido.PedidoVenda', db_column='pedido_venda_id', related_name='itens', on_delete=models.CASCADE)
-    pedido_forma_envio = models.ForeignKey('pedido.PedidoVendaFormaEnvio', db_column="pedido_venda_envio_id", related_name='pedido_venda_itens', null=True)
-    produto = models.ForeignKey("catalogo.Produto", related_name='pedido_venda_itens', on_delete=models.PROTECT)
-    produto_pai = models.ForeignKey("catalogo.Produto", db_column='produto_id_pai', related_name='filhos_pedido_venda_itens', null=True, on_delete=models.PROTECT)
-    conta = models.ForeignKey('plataforma.Conta', related_name='pedido_venda_itens')
-    contrato = models.ForeignKey('plataforma.Contrato', related_name='pedido_venda_itens')
+    pedido = models.ForeignKey(PedidoVenda, db_column='pedido_venda_id', related_name='itens', on_delete=models.CASCADE)
+    pedido_forma_envio = models.ForeignKey('repositories_pedido.PedidoVendaFormaEnvio', db_column="pedido_venda_envio_id", related_name='pedido_venda_itens', null=True)
+    produto = models.ForeignKey("repositories_catalogo.Produto", related_name='pedido_venda_itens', on_delete=models.PROTECT)
+    produto_pai = models.ForeignKey("repositories_catalogo.Produto", db_column='produto_id_pai', related_name='filhos_pedido_venda_itens', null=True, on_delete=models.PROTECT)
+    conta = models.ForeignKey('repositories_plataforma.Conta', related_name='pedido_venda_itens')
+    contrato = models.ForeignKey('repositories_plataforma.Contrato', related_name='pedido_venda_itens')
 
     class Meta:
-        app_label = "pedido"
+        app_label = "repositories_pedido"
         db_table = u"pedido\".\"tb_pedido_venda_item"
         verbose_name = u'Itens de um pedido de venda'
         verbose_name_plural = u"Itens dos pedidos de vendas"
@@ -420,3 +369,77 @@ class PedidoVendaItem(models.Model):
 
     def __unicode__(self):
         return unicode(self.id)
+
+
+class PedidoVendaSituacaoHistorico(models.Model):
+    """Histórico de situações de um pedido de venda.
+
+    O alterado_por pode receber três valores básicos:
+        cliente - Quando foi o cliente que alterou.
+        gateway - Quando a alteração foi feita pelo gateway de pagamento.
+        usuario - Sempre que o usuário alterar a situação.
+        sistema - Quando não é possível identificar quem fez a alteração.
+    """
+    ALTERADO_POR_CLIENTE = 'cliente'
+    ALTERADO_POR_GATEWAY = 'gateway'
+    ALTERADO_POR_USUARIO = 'usuario'
+    ALTERADO_POR_SISTEMA = 'sistema'
+
+    CHOICES_ALTERADO_POR = [
+        (ALTERADO_POR_CLIENTE, u'Cliente'),
+        (ALTERADO_POR_GATEWAY, u'Gateway'),
+        (ALTERADO_POR_USUARIO, u'Usuário'),
+        (ALTERADO_POR_SISTEMA, u'Sistema'),
+    ]
+
+    id = models.AutoField(db_column="pedido_venda_situacao_historico_id", primary_key=True)
+    data = models.DateTimeField(db_column="pedido_venda_situacao_historico_data", auto_now=True)
+    alterado_por = models.CharField(db_column="pedido_venda_situacao_historico_alterado_por", max_length=64, null=True, choices=CHOICES_ALTERADO_POR)
+    alterado_por_nome = models.CharField(db_column="pedido_venda_situacao_historico_alterado_por_nome", max_length=128, null=True)
+    obs = models.TextField(db_column="pedido_venda_situacao_historico_obs", null=True, default=None)
+
+    objects = MyObjects()
+
+    situacao_inicial = models.ForeignKey(PedidoVendaSituacao, db_column="pedido_venda_situacao_id_inicial", related_name='pedido_venda_situacao_inicial_historico')
+    situacao_final = models.ForeignKey(PedidoVendaSituacao, db_column="pedido_venda_situacao_id_final", related_name='pedido_venda_situacao_final_historico')
+    pedido = models.ForeignKey('repositories_pedido.PedidoVenda', db_column='pedido_venda_id', related_name='historico', on_delete=models.CASCADE)
+    conta = models.ForeignKey('repositories_plataforma.Conta', related_name='pedido_venda_situacao_historico')
+    # contrato = models.ForeignKey('repositories_plataforma.Contrato', related_name='pedido_venda_situacao_historico')
+
+    class Meta:
+        app_label = "repositories_pedido"
+        db_table = u"pedido\".\"tb_pedido_venda_situacao_historico"
+        verbose_name = u'Histórico de situações de um pedido de venda'
+        verbose_name_plural = u"Histórico de situações dos pedidos de vendas"
+        ordering = ['id']
+
+    def __unicode__(self):
+        return unicode(self.id)
+
+
+class PedidoVendaFormaEnvio(models.Model):
+    """Forma de envio de um pedido de venda."""
+    id = models.AutoField(db_column="pedido_venda_envio_id", primary_key=True)
+    objeto = models.CharField(db_column="pedido_venda_envio_objeto", max_length=32, null=True)
+    valor = models.DecimalField(db_column="pedido_venda_envio_valor", max_digits=16, decimal_places=2, null=True)
+    data_criacao = models.DateTimeField(db_column="pedido_venda_envio_data_criacao", auto_now_add=True)
+    data_modificacao = models.DateTimeField(db_column="pedido_venda_envio_data_modificacao", auto_now=True)
+    mensagem_correios = models.TextField(db_column="pedido_venda_envio_mensagem_correios", null=True, default=None)
+    prazo = models.IntegerField(db_column='pedido_venda_envio_prazo', null=True, default=None)
+
+    objects = MyObjects()
+
+    pedido = models.ForeignKey(PedidoVenda, db_column='pedido_venda_id', related_name='pedido_envios')
+    envio = models.ForeignKey('repositories_configuracao.Envio', related_name='pedidos_envio')
+    conta = models.ForeignKey('repositories_plataforma.Conta', related_name='pedido_venda_envios')
+    contrato = models.ForeignKey('repositories_plataforma.Contrato', related_name='pedido_venda_envios')
+
+    class Meta:
+        app_label = "repositories_pedido"
+        db_table = u"pedido\".\"tb_pedido_venda_envio"
+        verbose_name = u'Forma de envio de um pedido de venda'
+        verbose_name_plural = u"Formas de envios dos pedidos de vendas"
+        ordering = ['id']
+
+    def __unicode__(self):
+        return unicode(self.id)
