@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from ..models import MyObjects
+
 from django.db import models
 from jsonfield import JSONField
 
@@ -43,13 +44,13 @@ class Contrato(models.Model):
 
     objects = MyObjects()
 
-    colecao = models.ForeignKey('faturamento.Colecao', db_column="colecao_id")
+    colecao = models.ForeignKey('repositories_faturamento.Colecao', db_column="colecao_id")
 
     def __str__(self):              # __unicode__ on Python 2
         return "%s the restaurant" % self.dominio
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_contrato"
 
 
@@ -68,6 +69,7 @@ class Conta(models.Model):
     dominio = models.CharField(db_column="conta_loja_dominio", max_length=128, null=True, default=None)
     situacao = models.CharField(db_column="conta_situacao", max_length=32, null=False, default='ATIVA', choices=CONTA_SITUACOES)
     modo = models.CharField(db_column="conta_loja_modo", max_length=32, null=False, default="loja")
+    verificada = models.BooleanField(db_column="conta_verificada", default=False)
 
     logo = models.CharField(db_column="conta_logo", max_length=128, null=True, default=None)
     telefone = models.CharField(db_column="conta_loja_telefone", max_length=20, null=True, default=None)
@@ -87,11 +89,11 @@ class Conta(models.Model):
 
     objects = MyObjects()
 
-    contrato = models.ForeignKey('Contrato', db_column="contrato_id")
-    plano = models.ForeignKey('faturamento.Plano', db_column="plano_id")
+    contrato = models.ForeignKey(Contrato, db_column="contrato_id")
+    plano = models.ForeignKey('repositories_faturamento.Plano', db_column="plano_id")
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_conta"
 
     @property
@@ -127,10 +129,10 @@ class Dominio(models.Model):
 
     objects = MyObjects()
 
-    conta = models.ForeignKey("Conta", db_column="conta_id", related_name="dominios")
+    conta = models.ForeignKey(Conta, db_column="conta_id", related_name="dominios")
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"configuracao\".\"tb_dominio"
 
 
@@ -143,10 +145,10 @@ class Usuario(models.Model):
 
     objects = MyObjects()
 
-    conta_id = models.ManyToManyField('Conta', related_name="usuarios", through="ContaUsuario")
+    conta_id = models.ManyToManyField(Conta, related_name="usuarios", through="ContaUsuario")
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_usuario"
 
     @property
@@ -161,11 +163,11 @@ class ContaUsuario(models.Model):
 
     objects = MyObjects()
 
-    usuario = models.ForeignKey('Usuario', db_column="usuario_id")
-    conta = models.ForeignKey('Conta', db_column="conta_id")
+    usuario = models.ForeignKey(Usuario, db_column="usuario_id")
+    conta = models.ForeignKey(Conta, db_column="conta_id")
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_conta_usuario"
         unique_together = ('conta', 'usuario')
 
@@ -189,7 +191,7 @@ class Certificado(models.Model):
     objects = MyObjects()
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_certificado"
 
     def __unicode__(self):
@@ -216,12 +218,12 @@ class ContaCertificado(models.Model):
 
     objects = MyObjects()
 
-    certificado = models.ForeignKey('Certificado', related_name='contas', on_delete=models.CASCADE)
-    contrato = models.ForeignKey('Contrato', db_column="contrato_id")
-    conta = models.ForeignKey('Conta', db_column="conta_id")
+    certificado = models.ForeignKey(Certificado, related_name='contas', on_delete=models.CASCADE)
+    contrato = models.ForeignKey(Contrato, db_column="contrato_id")
+    conta = models.ForeignKey(Conta, db_column="conta_id")
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_conta_certificado"
 
 
@@ -242,9 +244,38 @@ class Imagem(models.Model):
 
     objects = MyObjects()
 
-    contrato = models.ForeignKey('Contrato', db_column="contrato_id")
-    conta = models.ForeignKey('Conta', db_column="conta_id")
+    contrato = models.ForeignKey(Contrato, db_column="contrato_id")
+    conta = models.ForeignKey(Conta, db_column="conta_id")
+
+    produtos = models.ManyToManyField('repositories_catalogo.Produto', through='repositories_catalogo.ProdutoImagem', related_name='produtos')
 
     class Meta:
-        app_label = 'plataforma'
+        app_label = 'repositories_plataforma'
         db_table = u"plataforma\".\"tb_imagem"
+
+class URL(models.Model):
+    """URLs dos recursos do sistema.
+
+    Define uma URL para um recurso da loja. Todas as URLs são únicas para a
+    loja. Cada recurso deve ter pelo menos uma URL principal, caso não tenha,
+    a URL mais nova é assumida como principal.
+    """
+
+    id = models.AutoField(db_column="url_id", primary_key=True)
+    data_criacao = models.DateTimeField(db_column="url_data_criacao", auto_now_add=True)
+    data_modificacao = models.DateTimeField(db_column="url_data_modificacao", auto_now=True)
+    url = models.CharField(db_column="url_canonical_url", max_length=1024, null=False)
+    principal = models.BooleanField(db_column="url_principal", default=True)
+
+    produto = models.ForeignKey("repositories_catalogo.Produto", related_name="urls", null=True, on_delete=models.CASCADE)
+    categoria = models.ForeignKey("repositories_catalogo.Categoria", related_name="urls", null=True, on_delete=models.CASCADE)
+    #marca = models.ForeignKey("repositories_catalogo.Marca", related_name="urls", null=True, on_delete=models.CASCADE)
+    #pagina = models.ForeignKey("repositories_plataforma.Pagina", related_name="urls", null=True, on_delete=models.CASCADE)
+
+    conta = models.ForeignKey("repositories_plataforma.Conta", related_name="urls")
+    contrato = models.ForeignKey("repositories_plataforma.Contrato", related_name="urls")
+
+    class Meta:
+        app_label = 'repositories_plataforma'
+        db_table = u"plataforma\".\"tb_url"
+#        unique_together = (("url", "conta", "contrato"),)
